@@ -4,8 +4,7 @@
  *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef ACTIVITIES_P_H
-#define ACTIVITIES_P_H
+#pragma once
 
 // Self
 #include "Activities.h"
@@ -46,12 +45,6 @@ public Q_SLOTS:
 public:
     void setActivityState(const QString &activity, Activities::State state);
 
-    // Configuration
-    class KDE4ConfigurationTransitionChecker
-    {
-    public:
-        KDE4ConfigurationTransitionChecker();
-    } kde4ConfigurationTransitionChecker;
     QTimer configSyncTimer;
     KConfig config;
 
@@ -59,7 +52,7 @@ public:
     KSMServer *ksmserver;
 
     QHash<QString, Activities::State> activities;
-    QVector<ActivityInfo> sortedActivities;
+    QList<ActivityInfo> sortedActivities;
     QReadWriteLock activitiesLock;
     QString currentActivity;
 
@@ -114,5 +107,3 @@ public Q_SLOTS:
 private:
     Activities *const q;
 };
-
-#endif // ACTIVITIES_P_H
