@@ -30,17 +30,16 @@
 #include "common/specialvalues.h"
 #include "resourcescoringadaptor.h"
 
-K_PLUGIN_CLASS_WITH_JSON(StatsPlugin, "kactivitymanagerd-plugin-sqlite.json")
+K_PLUGIN_CLASS(StatsPlugin)
 
 StatsPlugin *StatsPlugin::s_instance = nullptr;
 
-StatsPlugin::StatsPlugin(QObject *parent, const QVariantList &args)
+StatsPlugin::StatsPlugin(QObject *parent)
     : Plugin(parent)
     , m_activities(nullptr)
     , m_resources(nullptr)
     , m_resourceLinking(new ResourceLinking(this))
 {
-    Q_UNUSED(args);
     s_instance = this;
 
     new ResourcesScoringAdaptor(this);
@@ -78,8 +77,6 @@ void StatsPlugin::loadConfiguration()
     auto conf = config();
     conf.config()->reparseConfiguration();
 
-    const QString configFile = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QStringLiteral("kactivitymanagerd-pluginsrc");
-
     m_blockedByDefault = conf.readEntry("blocked-by-default", false);
     m_blockAll = false;
     m_whatToRemember = (WhatToRemember)conf.readEntry("what-to-remember", (int)AllApplications);
@@ -344,12 +341,12 @@ Event StatsPlugin::validateEvent(Event event)
 
 QStringList StatsPlugin::listActivities() const
 {
-    return Plugin::retrieve<QStringList>(m_activities, "ListActivities", "QStringList");
+    return Plugin::retrieve<QStringList>(m_activities, "ListActivities");
 }
 
 QString StatsPlugin::currentActivity() const
 {
-    return Plugin::retrieve<QString>(m_activities, "CurrentActivity", "QString");
+    return Plugin::retrieve<QString>(m_activities, "CurrentActivity");
 }
 
 void StatsPlugin::addEvents(const EventList &events)
@@ -367,7 +364,7 @@ void StatsPlugin::addEvents(const EventList &events)
 
     DATABASE_TRANSACTION(*resourcesDatabase());
 
-    for (auto event : eventsToProcess) {
+    for (const auto &event : eventsToProcess) {
         switch (event.type) {
         case Event::Accessed:
             openResourceEvent(currentActivity(), event.application, event.uri, event.timestamp, event.timestamp);
@@ -456,7 +453,7 @@ void StatsPlugin::DeleteRecentStats(const QString &activity, int count, const QS
         Utils::exec(*resourcesDatabase(), Utils::FailOnError, removeScoreCachesQuery, ":usedActivity", usedActivity, ":since", since.toSecsSinceEpoch());
     }
 
-    emit RecentStatsDeleted(activity, count, what);
+    Q_EMIT RecentStatsDeleted(activity, count, what);
 }
 
 void StatsPlugin::DeleteEarlierStats(const QString &activity, int months)
@@ -488,7 +485,7 @@ void StatsPlugin::DeleteEarlierStats(const QString &activity, int months)
 
     Utils::exec(*resourcesDatabase(), Utils::FailOnError, removeScoreCachesQuery, ":usedActivity", usedActivity, ":time", time.toSecsSinceEpoch());
 
-    emit EarlierStatsDeleted(activity, months);
+    Q_EMIT EarlierStatsDeleted(activity, months);
 }
 
 void StatsPlugin::DeleteStatsForResource(const QString &activity, const QString &client, const QString &resource)
@@ -527,7 +524,7 @@ void StatsPlugin::DeleteStatsForResource(const QString &activity, const QString
 
     Utils::exec(*resourcesDatabase(), Utils::FailOnError, removeScoreCachesQuery, ":targettedResource", pattern);
 
-    emit ResourceScoreDeleted(activity, client, resource);
+    Q_EMIT ResourceScoreDeleted(activity, client, resource);
 }
 
 bool StatsPlugin::isFeatureOperational(const QStringList &feature) const
@@ -641,3 +638,5 @@ QStringList StatsPlugin::listFeatures(const QStringList &feature) const
 }
 
 #include "StatsPlugin.moc"
+
+#include "moc_StatsPlugin.cpp"
