@@ -4,8 +4,7 @@
  *   SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-#ifndef PLUGINS_SQLITE_STATS_PLUGIN_H
-#define PLUGINS_SQLITE_STATS_PLUGIN_H
+#pragma once
 
 // Qt
 #include <QObject>
@@ -30,10 +29,9 @@ class StatsPlugin : public Plugin
 {
     Q_OBJECT
     // Q_CLASSINFO("D-Bus Interface", "org.kde.ActivityManager.Resources.Scoring")
-    // Q_PLUGIN_METADATA(IID "org.kde.ActivityManager.plugins.sqlite")
 
 public:
-    explicit StatsPlugin(QObject *parent = nullptr, const QVariantList &args = QVariantList());
+    explicit StatsPlugin(QObject *parent);
 
     static StatsPlugin *self();
 
@@ -130,5 +128,3 @@ private:
 
     static StatsPlugin *s_instance;
 };
-
-#endif // PLUGINS_SQLITE_STATS_PLUGIN_H
